nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Cfg6

Enum Cfg6 

#[repr(u8)]
pub enum Cfg6 { CONSTANT_HIGH = 0, STICKY_RISING_EDGE = 1, STICKY_FALLING_EDGE = 2, STICKY_RISING_FALLING_EDGE = 3, HIGH_LEVEL = 4, LOW_LEVEL = 5, CONSTANT_ZERO = 6, EVENT = 7, }

Variants



CONSTANT_HIGH = 0

Constant HIGH. This bit slice always contributes to a product term match.



STICKY_RISING_EDGE = 1

Sticky rising edge. Match occurs if a rising edge on the specified input has occurred since the last time the edge detection for this bit slice was cleared. This bit is only cleared when the PMCFG or the PMSRC registers are written to.



STICKY_FALLING_EDGE = 2

Sticky falling edge. Match occurs if a falling edge on the specified input has occurred since the last time the edge detection for this bit slice was cleared. This bit is only cleared when the PMCFG or the PMSRC registers are written to.



STICKY_RISING_FALLING_EDGE = 3

Sticky rising or falling edge. Match occurs if either a rising or falling edge on the specified input has occurred since the last time the edge detection for this bit slice was cleared. This bit is only cleared when the PMCFG or the PMSRC registers are written to.



HIGH_LEVEL = 4

High level. Match (for this bit slice) occurs when there is a high level on the input specified for this bit slice in the PMSRC register.



LOW_LEVEL = 5

Low level. Match occurs when there is a low level on the specified input.



CONSTANT_ZERO = 6

Constant 0. This bit slice never contributes to a match (should be used to disable any unused bit slices).



EVENT = 7

Event. Non-sticky rising or falling edge. Match occurs on an event - i.e. when either a rising or falling edge is first detected on the specified input (this is a non-sticky version of value 0x3) . This bit is cleared after one clock cycle.

Implementations

Source

impl Cfg6

pub const fn from_bits(val: u8) -> Cfg6

pub const fn to_bits(self) -> u8